@@ -1168,13 +1168,18 @@ usrp_write_aux_dac (struct usb_dev_handle *udh, int slot,
     return false;
   }
 
+  value &= 0x0fff;	// mask to 12-bits
+  
   if (which_dac == 3){
+    // dac 3 is really 12-bits.  Use value as is.
     bool r = true;
     r &= usrp_9862_write (udh, which_codec, 43, (value >> 4));       // most sig
     r &= usrp_9862_write (udh, which_codec, 42, (value & 0xf) << 4); // least sig
     return r;
   }
   else {
+    // dac 0, 1, and 2 are really 8 bits.  
+    value = value >> 4;		// shift value appropriately
     return usrp_9862_write (udh, which_codec, 36 + which_dac, value);
   }
 }
@@ -1224,14 +1229,14 @@ usrp_read_aux_adc (struct usb_dev_handle *udh, int slot,
   // start the conversion
   usrp_9862_write (udh, which_codec, 34, aux_adc_control);
 
-  // read the result back
+  // read the 10-bit result back
   unsigned char v_lo = 0;
   unsigned char v_hi = 0;
   bool r = usrp_9862_read (udh, which_codec, rd_reg, &v_lo);
   r &= usrp_9862_read (udh, which_codec, rd_reg + 1, &v_hi);
 
   if (r)
-    *value = (v_hi << 2) | ((v_lo >> 6) & 0x3);
+    *value = ((v_hi << 2) | ((v_lo >> 6) & 0x3)) << 2;	// format as 12-bit
   
   return r;
 }
